@@ -1,10 +1,10 @@
-from typing import Generic, TypeVar
+from typing import Generic
+from typing import TypeVar
 
 from pydantic.generics import GenericModel
 
 from mmisdk.bitgo.bitgo_response_meta import BitgoResponseMeta
 
-
 T = TypeVar("T")
 
 
