@@ -20,7 +20,7 @@ class Custodian(AbstractClient):
          Returns:
              The transaction of passed id.
          """
-        pass
+        raise NotImplementedError()
 
     @abstractmethod
     def get_transactions(self, chain_id=1) -> List[Transaction]:
@@ -32,7 +32,7 @@ class Custodian(AbstractClient):
         Returns:
             The transaction of passed id.
         """
-        pass
+        raise NotImplementedError()
 
     @abstractmethod
     def create_transaction(self, tx_params: Union[LegacyTxParams, EIP1559TxParams], extra_params) -> Transaction:
@@ -43,4 +43,4 @@ class Custodian(AbstractClient):
             tx_params: The params to create the transaction with. Must map to either a LegacyTxParams or EIP1559TxParams.
             extra_params: Custodian-specific extra parameters. Refer to the types[custodian]_create_tx_extra_params.py for specific values.
         """
-        pass
+        raise NotImplementedError()
